# Blockkurs Microbial Bioinformatics
Welcome to the home page of the Microbial Bioinformatics course. You can find and exercise instructions here (uploaded as we go along) as well as software that should be installed beforehand. 


## Communication, questions, etc...
If you want to contact us please reach out in [our MS teams](https://teams.microsoft.com/l/channel/19%3a7qjAc3uY_F6vPFYjNdp-aEivjy5Z4dCBS9XTT2BC8lU1%40thread.tacv2/General?groupId=8e5c5a6e-df88-47f7-8240-0dcec2f2cc92&tenantId=c7e438db-e462-4c22-a90a-c358b16980b3) (rather than writing an email to a specific person). It makes it easier for us to see and answer your questions. 


## Getting started

For connecting to ScienceCluster as well as writing your scripts, we recommend you download **Visual Studio Code** for Mac and Windows (https://code.visualstudio.com/download). You will also need to install [this extension to connect via SSH](https://marketplace.visualstudio.com/items?itemName%253Dms-vscode-remote.remote-ssh). 

### Connecting 

Open VSCode and click on the green \>\< symbol in the lower left corner. Then select `Connect to Host`, `Add new SSH Host` and then type

```bash
ssh <username>@cluster.s3it.uzh.ch
```

> **_NOTE:_**
 You need to be in the UZH VPN in order to connect to ScienceCluster. Please follow the instructions here:
[External UZH Network Access (VPN)](https://www.zi.uzh.ch/en/support/network/vpn_ISAC.html)




<!-- ### Windows 

Please download and install this command line tool to connect to Science Cluster.  
**MobaXTerm**  (http://mobaxterm.mobatek.net/)

A simple editor for code writing is for example **Notepad++** (https://notepad-plus-plus.org).  


### Macintosh

There is already an application called **Terminal** installed on your system. 
However, we recommend installing **Termius** (https://termius.com/download/macos) for easier file transfer to and from Science Cluster. You will have to create an account (or sign in with Google/Apple), but it's free. 

A simple editor with syntax highlighting would be for example **BBEdit** which you can install via the App Store.  -->


### Other software 

**IGV** Integrative Genomics Viewer (https://software.broadinstitute.org/software/igv/home)

**Figtree** (https://github.com/rambaut/figtree/releases) - Software to visualise phylogenetic trees. Please download and unpack/install the 
- zip for Windows
- dmg for MacOS 
- tgz for Linux 

**Bandage** (https://rrwick.github.io/Bandage/) - Software to visualise assembly graphs

**AliView** (http://www.ormbunkar.se/aliview) - Lightweight viewer for multiple sequence alignments 





## Course material

<!--- 
- [ ] [Welcome from Director of the IMM](slides/240314_Blockkurs_Egli_Intro_hss-on.pdf)
- [ ] [Introduction to the projects](slides/Introduction_projects_240314_TR.pdf)
- [ ] [Introduction to NGS and routine diagnostics](slides/Routine_diagnostics_NGS_240314_TR.pdf)
- [ ] [NGS technologies](slides/Sequencing_technologies_240314_TR.pdf)
- [ ] [Intro to NGS QC](slides/240315_TR_Intro_to_QC.pdf)


### Introduction to UNIX and HPC
- [ ] [Introduction to UNIX](slides/240319_intro_unix_containers.pdf)
- [ ] [Exercise instructions](exercises/UNIX_HPC_exercise_instructions.md)
- [ ] [Cheat sheet](exercises/UNIX_HPC_cheat_sheet.md)


### QC of sequencing data
- [ ] [Exercise instructions QC](exercises/qc_exercise.md)


### Genome assembly
- [ ] [Genome assembly](slides/240320_SP_TR_Assembly.pdf)
- [ ] [Exercise instructions](exercises/assembly_exercise.md)
- [ ] [Journal Club on Unicycler](slides/20240321_Unicycler_BIO296_ZG.pdf)
- [ ] [QC Assemblies lecture](slides/240321_TR_Assembly_QC.pdf)
- [ ] [Assembly QC exercise](exercises/assembly_exercise.md#assembly-quality-quast-metaquast-and-bandage)


### Typing
- [ ] [Intro to Typing](slides/240321_Blockkurs_HSS_Typing.pdf)
- [ ] [cgMLST](slides/240322_Blockkurs_HSS_cgMLST.pdf)
- [ ] [Journal Club on Typing](slides/20240322_blockkurs_journalclub_em.pdf)
- [ ] [Pangenome slides](exercises/Pangenome_analysis/Pangenome.pdf)

- [ ] [Discussion on Typing](slides/240323_Blockkurs_HSS_TypingDiscussion.pdf)

### Phylogenetics
- [ ] [Intro to Phylogenetics](slides/240327_intro_phylogenetics.pdf)
- [ ] [Phylo exercise](exercises/phylo_exercise.md)
- [ ] [Visualization of Phylogenies](slides/240409_Blockkurs_HSS_VisualisingPhylogeniesMetadata.pdf)


- [ ] [Journal Club on MRSA outbreak](slides/230330_Journal_Club_Elisa_MRSA_WGS.pdf)
- [ ] [Metadata and trees](slides/230331_Blockkurs_HSS_VisualisingPhylogeniesMetadata.pdf)
- [ ] [Metadata exercise](exercises/230331_Blockkurs_HSS_MetadataExercise.pdf)


### Resistence, virulence and diagnostic tests
- [ ] [Identification of AMR & Virulence genes](slides/240409_TR_Identifying_resistance_and_virulence_factors.pdf)
- [ ] [AMR & Virfinder exercise (webbased)](exercises/240409_Blockkurs_ZG_ResVirExercise.pdf)
- [ ] [AMR exercise abricate (command line)](exercises/abricate_exercise.md)
- [ ] [Virulence Factors](slides/240410_Blockkurs_Bioinformatik_Lecture_Bacterial_Virulence_final.pdf)
- [ ] [Primer design](exercises/230410_Blockkurs_TR_PrimerDesign2.pdf)
- [ ] [Journal Club on Virulence and Diagnostics](slides/20240410_JournalClub_Virulence_and_Diagnostics_YG.pdf)

### Wrap up
- [ ] [Farewell from Director of the IMM](slides/240412_Blockkurs_Farewell.pdf)
- [ ] [Wrap up slides](slides/230412_Blockkurs_TR_SummaryFeedback.pdf)

- [ ] [Case: Chlamydia](slides/230331_Blockkurs_HSS_Chlamydia.pdf)
--->

<br><br><br>

<!---
To make it easy for you to get started with GitLab, here's a list of recommended next steps.

Already a pro? Just edit this README.md and make it your own. Want to make it easy? [Use the template at the bottom](#editing-this-readme)!

## Add your files

- [ ] [Create](https://docs.gitlab.com/ee/user/project/repository/web_editor.html#create-a-file) or [upload](https://docs.gitlab.com/ee/user/project/repository/web_editor.html#upload-a-file) files
- [ ] [Add files using the command line](https://docs.gitlab.com/ee/gitlab-basics/add-file.html#add-a-file-using-the-command-line) or push an existing Git repository with the following command:

```
cd existing_repo
git remote add origin https://gitlab.uzh.ch/appliedmicrobiologyresearch/Blockkurs_MicrobialBioinfo.git
git branch -M master
git push -uf origin master
```

## Integrate with your tools

- [ ] [Set up project integrations](https://gitlab.uzh.ch/appliedmicrobiologyresearch/Blockkurs_MicrobialBioinfo/-/settings/integrations)

## Collaborate with your team

- [ ] [Invite team members and collaborators](https://docs.gitlab.com/ee/user/project/members/)
- [ ] [Create a new merge request](https://docs.gitlab.com/ee/user/project/merge_requests/creating_merge_requests.html)
- [ ] [Automatically close issues from merge requests](https://docs.gitlab.com/ee/user/project/issues/managing_issues.html#closing-issues-automatically)
- [ ] [Enable merge request approvals](https://docs.gitlab.com/ee/user/project/merge_requests/approvals/)
- [ ] [Automatically merge when pipeline succeeds](https://docs.gitlab.com/ee/user/project/merge_requests/merge_when_pipeline_succeeds.html)

## Test and Deploy

Use the built-in continuous integration in GitLab.

- [ ] [Get started with GitLab CI/CD](https://docs.gitlab.com/ee/ci/quick_start/index.html)
- [ ] [Analyze your code for known vulnerabilities with Static Application Security Testing(SAST)](https://docs.gitlab.com/ee/user/application_security/sast/)
- [ ] [Deploy to Kubernetes, Amazon EC2, or Amazon ECS using Auto Deploy](https://docs.gitlab.com/ee/topics/autodevops/requirements.html)
- [ ] [Use pull-based deployments for improved Kubernetes management](https://docs.gitlab.com/ee/user/clusters/agent/)
- [ ] [Set up protected environments](https://docs.gitlab.com/ee/ci/environments/protected_environments.html)

***

# Editing this README

When you're ready to make this README your own, just edit this file and use the handy template below (or feel free to structure it however you want - this is just a starting point!). Thank you to [makeareadme.com](https://www.makeareadme.com/) for this template.

## Suggestions for a good README
Every project is different, so consider which of these sections apply to yours. The sections used in the template are suggestions for most open source projects. Also keep in mind that while a README can be too long and detailed, too long is better than too short. If you think your README is too long, consider utilizing another form of documentation rather than cutting out information.

## Name
Choose a self-explaining name for your project.

## Description
Let people know what your project can do specifically. Provide context and add a link to any reference visitors might be unfamiliar with. A list of Features or a Background subsection can also be added here. If there are alternatives to your project, this is a good place to list differentiating factors.

## Badges
On some READMEs, you may see small images that convey metadata, such as whether or not all the tests are passing for the project. You can use Shields to add some to your README. Many services also have instructions for adding a badge.

## Visuals
Depending on what you are making, it can be a good idea to include screenshots or even a video (you'll frequently see GIFs rather than actual videos). Tools like ttygif can help, but check out Asciinema for a more sophisticated method.

## Installation
Within a particular ecosystem, there may be a common way of installing things, such as using Yarn, NuGet, or Homebrew. However, consider the possibility that whoever is reading your README is a novice and would like more guidance. Listing specific steps helps remove ambiguity and gets people to using your project as quickly as possible. If it only runs in a specific context like a particular programming language version or operating system or has dependencies that have to be installed manually, also add a Requirements subsection.

## Usage
Use examples liberally, and show the expected output if you can. It's helpful to have inline the smallest example of usage that you can demonstrate, while providing links to more sophisticated examples if they are too long to reasonably include in the README.

## Support
Tell people where they can go to for help. It can be any combination of an issue tracker, a chat room, an email address, etc.

## Roadmap
If you have ideas for releases in the future, it is a good idea to list them in the README.

## Contributing
State if you are open to contributions and what your requirements are for accepting them.

For people who want to make changes to your project, it's helpful to have some documentation on how to get started. Perhaps there is a script that they should run or some environment variables that they need to set. Make these steps explicit. These instructions could also be useful to your future self.

You can also document commands to lint the code or run tests. These steps help to ensure high code quality and reduce the likelihood that the changes inadvertently break something. Having instructions for running tests is especially helpful if it requires external setup, such as starting a Selenium server for testing in a browser.

## Authors and acknowledgment
Show your appreciation to those who have contributed to the project.

## License
For open source projects, say how it is licensed.

## Project status
If you have run out of energy or time for your project, put a note at the top of the README saying that development has slowed down or stopped completely. Someone may choose to fork your project or volunteer to step in as a maintainer or owner, allowing your project to keep going. You can also make an explicit request for maintainers.
--->
